@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Tmuxinator
   module Deprecations
     def rvm?
@@ -15,5 +17,13 @@ module Tmuxinator
     def cli_args?
       yaml["cli_args"]
     end
+
+    def pre?
+      yaml["pre"]
+    end
+
+    def post?
+      yaml["post"]
+    end
   end
 end
