@@ -36,36 +36,49 @@ module Tmuxinator
     `on_project_exit`) and will be removed in a future release.
     M
 
-    attr_reader :yaml
-    attr_reader :force_attach
-    attr_reader :force_detach
-    attr_reader :custom_name
+    attr_reader :yaml, :force_attach, :force_detach, :custom_name,
+                :no_pre_window
 
-    def self.load(path, options = {})
-      yaml = begin
-        args = options[:args] || []
-        @settings = parse_settings(args)
-        @args = args
+    class << self
+      include Tmuxinator::Util
 
-        content = render_template(path, binding)
-        YAML.safe_load(content, aliases: true)
-             rescue SyntaxError, StandardError => error
-               raise "Failed to parse config file: #{error.message}"
+      def load(path, options = {})
+        yaml = begin
+          args = options[:args] || []
+          @settings = parse_settings(args)
+          @args = args
+
+          content = render_template(path, binding)
+          YAML.safe_load(content, aliases: true)
+        rescue SyntaxError, StandardError => e
+          raise "Failed to parse config file: #{e.message}"
+        end
+
+        new(yaml, options)
       end
 
-      new(yaml, options)
-    end
+      def parse_settings(args)
+        settings = args.select { |x| x.match(/.*=.*/) }
+        args.reject! { |x| x.match(/.*=.*/) }
 
-    def self.parse_settings(args)
-      settings = args.select { |x| x.match(/.*=.*/) }
-      args.reject! { |x| x.match(/.*=.*/) }
+        settings.map! do |setting|
+          parts = setting.split("=", 2)
+          [parts[0], parts[1]]
+        end
 
-      settings.map! do |setting|
-        parts = setting.split("=")
-        [parts[0], parts[1]]
+        Hash[settings]
       end
 
-      Hash[settings]
+      def active
+        Tmuxinator::Config.configs(active: true).
+          map { |config| Config.validate(name: config) }
+      end
+
+      def stop_all
+        active.
+          sort_by { |project| project.name == current_session_name ? 1 : 0 }.
+          each { |project| Kernel.system(project.kill) }
+      end
     end
 
     def validate!
@@ -83,17 +96,31 @@ module Tmuxinator
 
       @yaml = yaml
 
-      @custom_name = options[:custom_name]
+      set_instance_variables_from_options(options)
 
-      @force_attach = options[:force_attach]
-      @force_detach = options[:force_detach]
-
-      raise "Cannot force_attach and force_detach at the same time" \
-        if @force_attach && @force_detach
+      validate_options
 
       extend Tmuxinator::WemuxSupport if wemux?
     end
 
+    def set_instance_variables_from_options(options)
+      @custom_name = options[:custom_name]
+      @force_attach = options[:force_attach]
+      @force_detach = options[:force_detach]
+      @append = options[:append]
+      @no_pre_window = options[:no_pre_window]
+    end
+
+    def validate_options
+      if @force_attach && @force_detach
+        raise "Cannot force_attach and force_detach at the same time"
+      end
+
+      if append? && !tmux_has_session?(name)
+        raise "Cannot append to a session that does not exist"
+      end
+    end
+
     def render
       self.class.render_template(Tmuxinator::Config.template, binding)
     end
@@ -121,26 +148,33 @@ module Tmuxinator
     end
 
     def name
-      name = custom_name || yaml["project_name"] || yaml["name"]
+      name =
+        if append?
+          current_session_name
+        else
+          custom_name || yaml["project_name"] || yaml["name"]
+        end
+
       blank?(name) ? nil : name.to_s.shellescape
     end
 
+    def append?
+      @append
+    end
+
     def pre
       pre_config = yaml["pre"]
       parsed_parameters(pre_config)
     end
 
     def attach?
-      yaml_attach = if yaml["attach"].nil?
-                      true
-                    else
-                      yaml["attach"]
-                    end
-      attach = force_attach || !force_detach && yaml_attach
-      attach
+      yaml_attach = yaml["attach"].nil? || yaml["attach"]
+      force_attach || !force_detach && yaml_attach
     end
 
     def pre_window
+      return if no_pre_window
+
       params = if rbenv?
                  "rbenv shell #{yaml['rbenv']}"
                elsif rvm?
@@ -167,6 +201,8 @@ module Tmuxinator
     end
 
     def tmux_has_session?(name)
+      return false unless name
+
       # Redirect stderr to /dev/null in order to prevent "failed to connect
       # to server: Connection refused" error message and non-zero exit status
       # if no tmux sessions exist.
@@ -208,7 +244,13 @@ module Tmuxinator
       end
     end
 
+    def last_window_index
+      `tmux list-windows -F '#I'`.split.last.to_i
+    end
+
     def base_index
+      return last_window_index + 1 if append?
+
       get_base_index.to_i
     end
 
@@ -241,7 +283,7 @@ module Tmuxinator
     end
 
     def window(index)
-      "#{name}:#{index}"
+      append? ? ":#{index}" : "#{name}:#{index}"
     end
 
     def send_pane_command(cmd, window_index, _pane_index)
@@ -329,6 +371,8 @@ module Tmuxinator
     end
 
     def tmux_new_session_command
+      return if append?
+
       window = windows.first.tmux_window_name_option
       "#{tmux} new-session -d -s #{name} #{window}"
     end
@@ -361,17 +405,16 @@ module Tmuxinator
 
     def pane_title_position_not_valid_warning
       print_warning(
-        "The specified pane title position " +
-        "\"#{yaml['pane_title_position']}\" is not valid. " +
-        "Please choose one of: top, bottom, or off."
+        "The specified pane title position '#{yaml['pane_title_position']}' " \
+        "is not valid. Please choose one of: top, bottom, or off."
       )
     end
 
     def pane_titles_not_supported_warning
       print_warning(
-        "You have enabled pane titles in your configuration, " +
-        "but the feature is not supported by your version of tmux.\n" +
-        "Please consider upgrading to a version that supports it (tmux >=2.6)."
+        "You have enabled pane titles in your configuration, but the " \
+        "feature is not supported by your version of tmux.\nPlease consider " \
+        "upgrading to a version that supports it (tmux >=2.6)."
       )
     end
 
