@@ -12,5 +12,9 @@ module Tmuxinator
     def yes_no(condition)
       condition ? say("Yes", :green) : say("No", :red)
     end
+
+    def current_session_name
+      `[[ -n "${TMUX+set}" ]] && tmux display-message -p "#S"`.strip
+    end
   end
 end
