@@ -99,11 +99,18 @@ describe Tmuxinator::Cli do
           end
 
           it "should call #start" do
-            instance = instance_double(cli)
-            expect(cli).to receive(:new).and_return(instance)
-            expect(instance).to receive(:start).with(*args)
+            expect(cli).to receive(:start).with([:start, *args])
             subject
           end
+
+          context "and the append option is passed" do
+            let(:args) { ["sample", "--append"] }
+
+            it "should call #start" do
+              expect(cli).to receive(:start).with([:start, *args])
+              subject
+            end
+          end
         end
 
         context "a thor command" do
@@ -191,21 +198,24 @@ describe Tmuxinator::Cli do
 
     it "lists the commands" do
       out, _err = capture_io { cli.start }
-      expected = %w(commands
-                    completions
-                    new
-                    edit
-                    open
-                    start
-                    stop
-                    local
-                    debug
-                    copy
-                    delete
-                    implode
-                    version
-                    doctor
-                    list)
+      expected = %w(
+        commands
+        completions
+        copy
+        debug
+        delete
+        doctor
+        edit
+        implode
+        local
+        list
+        new
+        open
+        start
+        stop
+        stop_all
+        version
+      )
       expect(out).to eq "#{expected.join("\n")}\n"
     end
   end
@@ -372,6 +382,20 @@ describe Tmuxinator::Cli do
     end
   end
 
+  describe "#stop_all" do
+    before do
+      allow(Tmuxinator::Config).to receive_messages(validate: project)
+      allow(Tmuxinator::Config).to receive_messages(version: 1.9)
+    end
+
+    it "stops all projects" do
+      ARGV.replace(["stop-all", "--noconfirm"])
+      out, err = capture_io { cli.start }
+      expect(err).to eq ""
+      expect(out).to eq ""
+    end
+  end
+
   describe "#local" do
     before do
       allow(Tmuxinator::Config).to receive_messages(validate: project)
@@ -900,7 +924,7 @@ describe Tmuxinator::Cli do
       end
 
       it "should generate a project file" do
-        new_path = described_class.new.find_project_file(name, false)
+        new_path = described_class.new.find_project_file(name, local: false)
         expect(new_path).to eq path
         expect(File).to exist new_path
       end
@@ -922,7 +946,7 @@ describe Tmuxinator::Cli do
       end
 
       it "should _not_ generate a new project file" do
-        new_path = described_class.new.find_project_file(name, false)
+        new_path = described_class.new.find_project_file(name, local: false)
         expect(new_path).to eq path
         expect(File).to exist new_path
         expect(File.read(new_path)).to match %r{#{extra}}
